@@ -1,15 +1,12 @@
 package Smart::Match;
-{
-  $Smart::Match::VERSION = '0.007';
-}
-
+$Smart::Match::VERSION = '0.008';
 use 5.010001;
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 use experimental 'smartmatch';
 
 use Carp qw/croak/;
-use List::MoreUtils qw//;
+use List::Util 1.33 qw//;
 use Scalar::Util qw(blessed looks_like_number refaddr);
 
 use Smart::Match::Overload;
@@ -25,8 +22,8 @@ use Sub::Exporter::Progressive -setup => {
 		numwise stringwise
 		string string_length
 		object instance_of ref_type
-		array array_length tuple head sequence contains sorted sorted_by
-		hash hash_keys hash_values sub_hash hashwise
+		array array_length tuple head sequence contains contains_any sorted sorted_by
+		hash hash_keys hash_values sub_hash hashwise keywise
 		address value
 	/],
 	groups => {
@@ -38,8 +35,8 @@ use Sub::Exporter::Progressive -setup => {
 		meta     => [qw/match delegate/],
 		string   => [qw/string string_length/],
 		refs     => [qw/object instance_of ref_type/],
-		arrays   => [qw/array array_length tuple head sequence contains sorted/],
-		hashes   => [qw/hash hash_keys hash_values sub_hash/],
+		arrays   => [qw/array array_length tuple head sequence contains contains_any sorted/],
+		hashes   => [qw/hash hash_keys hash_values sub_hash hashwise keywise/],
 		direct   => [qw/address value/],
 	},
 };
@@ -176,7 +173,7 @@ sub instance_of {
 
 sub ref_type {
 	my $type = shift;
-	return match { ref eq $type };
+	return match { !blessed($_) && ref eq $type };
 }
 
 sub address {
@@ -188,7 +185,7 @@ use constant array => ref_type('ARRAY');
 
 sub array_length {
 	my $match = shift;
-	return match { scalar array and @{$_} + 0 ~~ $match };
+	return match { scalar array and scalar(@{$_}) ~~ $match };
 }
 
 sub tuple {
@@ -198,7 +195,7 @@ sub tuple {
 
 sub sequence {
 	my $matcher = shift;
-	return match { scalar array and List::MoreUtils::all { $_ ~~ $matcher } @{$_} };
+	return match { scalar array and List::Util::all { $_ ~~ $matcher } @{$_} };
 }
 
 sub head {
@@ -210,7 +207,15 @@ sub contains {
 	my @matchers = @_;
 	return match {
 		my $lsh = $_;
-		$_ ~~ array and List::MoreUtils::all { my $matcher = $_; List::MoreUtils::any { $_ ~~ $matcher } @{$lsh} } @matchers;
+		$_ ~~ array and List::Util::all { my $matcher = $_; List::Util::any { $_ ~~ $matcher } @{$lsh} } @matchers;
+	};
+}
+
+sub contains_any {
+	my @matchers = @_;
+	return match {
+		my $lsh = $_;
+		$_ ~~ array and List::Util::any { my $matcher = $_; List::Util::any { $_ ~~ $matcher } @{$lsh} } @matchers;
 	};
 }
 
@@ -241,13 +246,18 @@ sub sub_hash {
 	return match {
 		my $lhs = $_; # for grep { }
 
-		$lhs ~~ hash and keys %{$lhs} >= keys %{$hash} and List::MoreUtils::all { exists $lhs->{$_} } keys %{$hash} and [ @{$lhs}{keys %{$hash}} ] ~~ [ values %{$hash} ];
+		$lhs ~~ hash and keys %{$lhs} >= keys %{$hash} and List::Util::all { exists $lhs->{$_} } keys %{$hash} and [ @{$lhs}{keys %{$hash}} ] ~~ [ values %{$hash} ];
 	};
 }
 
 sub hashwise {
 	my $hash = shift;
-	return match { scalar hash and hash_keys(sorted([ sort keys %{$hash} ])) and [ @{$_}{keys %{$hash}} ] ~~ [ values %{$hash} ] };
+	return match { scalar hash and [ sort keys %{$_} ] ~~ [ sort keys %{$hash} ] and [ @{$_}{ keys %{$hash}} ] ~~ [ values %{$hash} ] };
+}
+
+sub keywise {
+	my $hash = shift;
+	return match { scalar hash and [ sort keys %{$_} ] ~~ [ sort keys %{$hash} ] };
 }
 
 sub value {
@@ -284,13 +294,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Smart::Match - Smart matching utilities
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 SYNOPSIS
 
@@ -320,6 +332,8 @@ will also do what you mean.
 
 =head1 FUNCTIONS
 
+This module optionally exports all described functions, but none are exported by default.
+
 =head2 always()
 
 This always matches.
@@ -444,9 +458,13 @@ Matches a list whose head elements match C<@entries> one by one.
 
 Matches a list whose elements all match C<$matcher>.
 
-=head2 contains(@matcher)
+=head2 contains(@matchers)
 
-Matches a list that for all of C<@matcher>s contains a matching element.
+Matches a list that contains a matching element for all of C<@matchers>.
+
+=head2 contains_any(@matcher)
+
+Matches a list that contains a matching element for any of C<@matchers>.
 
 =head2 sorted($matcher)
 
@@ -464,6 +482,10 @@ Matches any unblessed hash.
 
 Matches a hash for against C<$hashref>. The keys must be identical, and all keys in the hash much smartmatch the keys in $hashref.
 
+=head2 keywise($hashref)
+
+Matches a hash for against C<$hashref>. The keys must be identical.
+
 =head2 hash_keys($matcher)
 
 Match a list of hash keys against C<$matcher>.
