@@ -1,9 +1,7 @@
 package Smart::Match::Overload;
-{
-  $Smart::Match::Overload::VERSION = '0.007';
-}
+$Smart::Match::Overload::VERSION = '0.008';
 use strict;
-use warnings FATAL => 'all';
+use warnings;
 use XSLoader;
 
 XSLoader::load(__PACKAGE__, __PACKAGE__->VERSION);
@@ -23,19 +21,21 @@ sub new {
 
 1;
 
-# A class for closure based matcher objects.
+# ABSTRACT: An internal class for closure based matcher objects.
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Smart::Match::Overload
+Smart::Match::Overload - An internal class for closure based matcher objects.
 
 =head1 VERSION
 
-version 0.007
+version 0.008
 
 =head1 METHODS
 
